@@ -10,7 +10,9 @@
  *     (i)  M. Awramik, M. Czakon, A. Freitas and G. Weiglein                     *
  *          Phys. Rev. D 69, 053006 (2004), [hep-ph/0311148]                      *
  *                                                                                *
- *    (ii)  A. Freitas, arXiv:1401.2477                                           *
+ *    (ii)  update of above reference (v2), as on Dec 29th 2014,                  *
+ *          including the four-loop QCD correction O(alpha*alpha_s^3*mt^2)        * 
+ *          and an updated value of GF                                            *
  *                                                                                *
  * see corresponding .h file for author and license information                   *
  *                                                                                *     
@@ -43,12 +45,6 @@ GEW::MW::MW()
    SetTheoryName( GetName() );
    SetExistDerivative( kFALSE );
   
-   m_fourLoopCorr = kTRUE ;
-   if ( gStore()->ExistVariable( "GEWFlags::FourLoopCorr4Mw" ) ) {
-     m_fourLoopCorr = gStore()->GetVariable( "GEWFlags::FourLoopCorr4Mw" )->GetBoolValue();
-   }
-   m_logger << kINFO << "Using four-loop correction for MW: " << m_fourLoopCorr << GEndl;
-
    const TString& logMH = gStore()->GetVariable( "GEWFlags::logMH" )->GetStringValue();
    m_logger << kINFO << "Using logMH: \"" << logMH << "\"" << GEndl;
    
@@ -71,24 +67,26 @@ GEW::MW::MW()
 }
 
 // init coefficients
-// eq. (8) from (i)
+// eq. (8) from (i) and update in (ii)
 void GEW::MW::Initialise()
 {
-   m_MW0 = 80.3799;
-   m_c1  = 0.05429;
-   m_c2  = 0.008939;
-   m_c3  = 0.0000890;
-   m_c4  = 0.000161;
-   m_c5  = 1.070;
-   m_c6  = 0.5256;
-   m_c7  = 0.0678;
-   m_c8  = 0.00179;
-   m_c9  = 0.0000659;
-   m_c10 = 0.0737;
+   
+   m_MW0 = 80.3779;
+   m_c1 = 0.05427;
+   m_c2 = 0.008931;
+   m_c3 = 0.0000882;
+   m_c4 = 0.000161;
+   m_c5 = 1.070;
+   m_c6 = 0.5237;
+   m_c7 = 0.0679;
+   m_c8 = 0.00179;
+   m_c9 = 0.0000664;
+   m_c10 = 0.0795;
    m_c11 = 114.9;
+   
 }
 
-// eq. (6) and (7) from (i)
+// eq. (6) and (7) from (i) and (ii)
 Double_t GEW::MW::GetTheoryPrediction()
 {
 
@@ -109,7 +107,7 @@ Double_t GEW::MW::GetTheoryPrediction()
    Double_t dZ          = (p_MZ/91.1875) - 1.0;
 
    Double_t deAlpha     = (GetDAlphaQED().DAlphaQEDMZ()/0.05907) - 1.0;
-   Double_t deAlphaS    = (GetAlphasMZ()/0.119) - 1.0;   
+   Double_t deAlphaS    = (GetAlphasMZ()/0.119) - 1.0;  
 
    bool print = false;
    if (print){
@@ -125,36 +123,9 @@ Double_t GEW::MW::GetTheoryPrediction()
                    + m_c4*(dH-1) - m_c5*deAlpha 
                    + m_c6*dt - m_c7*dt*dt - m_c8*LogH*dt 
                    + m_c9*dH*dt - m_c10*deAlphaS + m_c11*dZ );
-
-   if (print) std::cout << "MW (old param.) = " << mw << std::endl;
    
-   Double_t alphaQEDMZ = GetDAlphaQED().AlphaQEDMZFull();
-   Double_t as_mt = GetAlphasRun().EvolveAlphas( p_mt );
-   
-   // correction due to O(alpha*mt * alphas^3) term as included in (ii)
-   // correction to parametrisation formula obtained from A. Freitas, personal correspondence
-   Double_t dmw_num = -0.39831 * alphaQEDMZ*alphaQEDMZ * as_mt*as_mt*as_mt * p_mt*p_mt * p_MZ*p_MZ;
-   Double_t dmw_den = p_GF * TMath::Power(p_MZ*p_MZ-mw*mw,2) * 
-     TMath::Sqrt( 1 - (2*GMath::Sqrt2()*alphaQEDMZ*TMath::Pi()) / (p_GF*p_MZ*p_MZ) ); 
-   Double_t dmw = dmw_num / dmw_den;
-   Double_t mw_new = mw;
-   if ( m_fourLoopCorr ) { mw_new = TMath::Sqrt(mw*mw + dmw); }
+   if (print) std::cout << "MW without theo unc = " << mw << std::endl;
 
-   if (print || TMath::IsNaN(dmw_den)){ 
-     std::cout << "alphaQED(MZ) = " << alphaQEDMZ << std::endl;
-     std::cout << "alphas(mt) = " << as_mt << std::endl;
-     std::cout << "squared shift term = " << dmw << std::endl;
-     std::cout << "1 = " << TMath::Power(p_MZ*p_MZ-mw*mw,2) << " 2 = " << TMath::Sqrt( 1 - (2*GMath::Sqrt2()*alphaQEDMZ*TMath::Pi()) / (p_GF*p_MZ*p_MZ) )
-	       << " 3 = " << (2*GMath::Sqrt2()*alphaQEDMZ*TMath::Pi()) / (p_GF*p_MZ*p_MZ) << std::endl;
-     std::cout << "MZ = " << p_MZ << std::endl;
-     std::cout << "mw = " << mw << " mw_new = " << mw_new << std::endl;
-     std::cout << "MW (with new correction) = " << mw_new << std::endl;
-     std::cout << "shift due to O(alpha*mt alphas^3) term = " << mw - mw_new << std::endl;
-   }
-
-   // use new value by default
-   mw = mw_new;
-   
    // theoretical uncertainty in MW
    // eq. (10) from (i)
    mw = mw + (1.0 - p_DeltaMW_Scale)*0.004;
@@ -175,16 +146,11 @@ Double_t GEW::MW::GetTheoryPrediction()
      m_logger << kWARNING << "MH = " << MH << " LogH = " << LogH << " dH = " << dH << " dt = " 
 	      << dt << " dZ = " << dZ << " deAlpha = " << deAlpha 
 	      << " deAlphaS = " << deAlphaS << GEndl;
+     Double_t alphaQEDMZ  = GetDAlphaQED().AlphaQEDMZFull(); 
      m_logger << kWARNING <<"alphaQED(MZ) = " << alphaQEDMZ << GEndl;
-     m_logger << kWARNING <<"alphas(mt) = " << as_mt << " GF = " << p_GF << GEndl;
-     m_logger << kWARNING <<"dmw_num = " << dmw_num << " dmw_den = " << dmw_den << GEndl;
-     m_logger << kWARNING <<"squared shift term = " << dmw << GEndl;
-     m_logger << kWARNING <<"MW (with new correction) = " << mw_new << GEndl;
-     m_logger << kWARNING <<"shift due to O(alpha*mt alphas^3) term = " << mw - mw_new << GEndl;
      m_logger << kFATAL << "p_MZ = " << p_MZ << " p_mt = " << p_mt << " MH = " << GetMH().GetValue()
            << " alpha_s = " << GetAlphasMZ()+0.0 << " alpha = " << GetDAlphaQED().DAlphaQEDMZ() << GEndl;
-     ///mw = 80.0;
    }
-   
+
    return mw;
 }
