@@ -111,7 +111,7 @@ Gfitter::GParameter::GParameter( TString parName, TString parAlias, Bool_t activ
          m_scanRange = new GInterval( tmpDataCurve->GetMin(), tmpDataCurve->GetMax() );
       }
 
-      // set reasonable fit range
+      // set reasonable fit range 
       m_fitRange = new GInterval( tmpDataCurve->GetMin(), tmpDataCurve->GetMax() );
       m_fitStep  = m_fitRange->GetWidth()/10.0;
 
@@ -358,14 +358,16 @@ void Gfitter::GParameter::InitFitRanges()
 {
    // reset fit ranges only if data object is GData (as opposed to a data curve)
    GData* tmpData = dynamic_cast<GData*>(m_data);
-   if (tmpData != 0) { //it is a GData
+	if (tmpData != 0) { //it is a GData
 
-      if (m_fitRange != 0) delete m_fitRange;
-      
-      // set reasonable fit range
+		if (m_fitRange != 0) delete m_fitRange;
+
+		// set reasonable fit range
       if (tmpData->GetErrGaussm() != 0 || HasScalers()) {
-         m_fitRange = new GInterval( 0, 0 ); // no limits (preferred by Minuit)
+			m_logger << kINFO << "Setting fit range for parameter \"" << GetFullName() << "\" to [0,0]" << GEndl;
+			m_fitRange = new GInterval( 0, 0 ); // no limits (preferred by Minuit)
          m_fitStep  = 0.5*tmpData->GetErrTotSym();
+			m_logger << kINFO << "Setting fit step for parameter \"" << GetFullName() << "\" to " << m_fitStep << GEndl;
 
          // print warning message: a parameter with solely a theoretical error cannot 
          // (usually) have scalers, since the chi2 function will have a discontinuity at 
@@ -381,7 +383,10 @@ void Gfitter::GParameter::InitFitRanges()
       else {                  
          m_fitRange = new GInterval(  tmpData->GetValue() - tmpData->GetErrRangem(), 
                                       tmpData->GetValue() + tmpData->GetErrRangep() );         
+			m_logger << kINFO << "Setting fit range for parameter \"" << GetFullName() << "\" to ["
+						<< tmpData->GetValue() - tmpData->GetErrRangem() << "," << tmpData->GetValue() + tmpData->GetErrRangep() << "]" << GEndl;
          m_fitStep  = m_fitRange->GetWidth()/10.0;
+			m_logger << kINFO << "Setting fit step for parameter \"" << GetFullName() << "\" to " << m_fitStep << GEndl;
       }
    }
 }
@@ -449,17 +454,110 @@ Double_t Gfitter::GParameter::GetDeviation( Int_t& sign, TFormula* formula ) con
    }
    // else: parameter within bounds of theory error --> no effective delta
 
-   // m_logger << kINFO << GetParName() << " : " << compval << " : " 
-   //          << v << " : " << rmin << " : " << rmax << " : " << sign << " : " << retval << GEndl;
+   //m_logger << kINFO << GetParName() << " : " << compval << " : " 
+   //	    << v << " : " << rmin << " : " << rmax << " : " << sign << " : " << retval << GEndl;
    
    return retval;
 }
 
+
+Double_t Gfitter::GParameter::GetChiSquared() const
+{
+   GData* tmpData = dynamic_cast<GData*>(m_data);
+   Double_t chi2( 0 );
+ 
+   // it is a GData object
+   if (tmpData != 0) {     
+
+     if (true) {
+       Double_t dx(0.);
+       Double_t h(0.);
+       
+       // default return value
+       Double_t m  = HasTheory() ? GetTheory()->GetPrediction() : GetFitValue();   
+       
+       // theory range
+       Double_t v    = GetValue( *tmpData );
+       
+       Double_t mL = v - tmpData->GetErrRangem();
+       Double_t mR = v + tmpData->GetErrRangep();
+       Double_t sigmaL = GetErrGaussm(); //!=0 ? GetErrGaussm() :  );
+       Double_t sigmaR = GetErrGaussp(); //!=0 ? GetErrGaussp() :  );
+       
+       if ( sigmaL==0 && tmpData->GetErrRangem()!=0 ) { sigmaL = tmpData->GetErrRangem() / 100.; }
+       if ( sigmaR==0 && tmpData->GetErrRangep()!=0 ) { sigmaR = tmpData->GetErrRangep() / 100.; }
+       
+       const Double_t mM = (mR+mL)/2.;
+       const Double_t height = ( mL!=mR ? 0.0001 : 0.0 );
+       const Double_t norm = height/(0.25*(mR*mR + mL*mL - 2.*mR*mL)) ;
+       
+       const Double_t mL_cont = ((mL/(sigmaL*sigmaL))-norm*mM)/((1/(sigmaL*sigmaL))-norm);
+       const Double_t mR_cont = ((mR/(sigmaR*sigmaR))-norm*mM)/((1/(sigmaR*sigmaR))-norm);
+       const Double_t heightL = norm*(mL_cont-mM)*(mL_cont-mM) - (mL_cont-mL)*(mL_cont-mL)/(sigmaL*sigmaL);
+       const Double_t heightR = norm*(mR_cont-mM)*(mR_cont-mM) - (mR_cont-mR)*(mR_cont-mR)/(sigmaR*sigmaR);
+       
+       if ((mL!=mR) && (m>=mL_cont) && (m<=mR_cont)) {
+	 dx=m-mM; 
+	 chi2 = norm*(dx*dx);
+	 //return 0.;
+       } else if ((mL!=mR) && ((m<mL_cont) || (m>mR_cont))) {
+	 if (m-mL_cont<0) { dx=m-mL; h=heightL; }
+	 if (m-mR_cont>0) { dx=m-mR; h=heightR; }
+	 double sigma = dx<0 ? sigmaL : sigmaR ;
+	 chi2 = (dx*dx)/(sigma*sigma) + h ; 
+       } else if (mL==mR) {
+	 if (m-mL<0) { dx=m-mL; }
+	 if (m-mR>0) { dx=m-mR; }
+	 double sigma = dx<0 ? sigmaL : sigmaR ;
+	 chi2 = (dx*dx)/(sigma*sigma); 
+       }
+       
+       //m_logger << kINFO << GetParName() << " : " << m << " : " 
+       //	       << v << " : " << " tL=" << tmpData->GetErrRangem() << " tR=" << tmpData->GetErrRangep()
+       //       << " eL=" << GetErrGaussm() << " eR=" <<  GetErrGaussp() 
+       //       << " chi2=" << chi2
+       //       << GEndl;
+     } else { // old
+       Int_t    sign( 0 );
+       Double_t delta = GetDeviation( sign );
+       
+       if (delta == 0) chi2 = 0; // within theory bounds
+       
+       // compute chi-squared a la Rfit, assuming for the time being 
+       // that parameters are unbound and uncorrelated
+       
+       else if (sign < 0) chi2 = delta/GetErrGaussm()*delta/GetErrGaussm();
+       else if (sign > 0) chi2 = delta/GetErrGaussp()*delta/GetErrGaussp();
+     }
+   }
+   // it is a GDataCurve or GWorkspace
+   else { 
+     Double_t fitValue = HasTheory() ? GetTheory()->GetPrediction() : GetFitValue(); 
+     
+     GDataCurve* tmpDataCurve = dynamic_cast<GDataCurve*>(m_data);
+     if (tmpDataCurve!=0) {
+       chi2 = tmpDataCurve->GDataCurve::GetChiSquared(fitValue);
+       return chi2;
+     }
+     
+     GWorkspace* tmpWorkspace = dynamic_cast<GWorkspace*>(m_data);
+     if (tmpWorkspace!=0) {
+       chi2 = tmpWorkspace->GWorkspace::GetChiSquared();
+       return chi2;
+     }
+   }
+   
+   return chi2;
+}
+
+/*
 Double_t Gfitter::GParameter::GetChiSquared() const
 {
    GData* tmpData = dynamic_cast<GData*>(m_data);
    Double_t retval( 0 );
    if (tmpData != 0) { //it is a GData    
+
+
       Int_t    sign( 0 );
       Double_t delta = GetDeviation( sign );
       
@@ -470,6 +568,12 @@ Double_t Gfitter::GParameter::GetChiSquared() const
       
       else if (sign < 0) retval = delta/GetErrGaussm()*delta/GetErrGaussm();
       else if (sign > 0) retval = delta/GetErrGaussp()*delta/GetErrGaussp();
+
+      m_logger << kINFO << GetParName() << " tL=" << tmpData->GetErrRangem() << " tR=" << tmpData->GetErrRangep()
+	       << " eL=" << GetErrGaussm() << " eR=" <<  GetErrGaussp() 
+	       << " delta=" << delta << " retval=" << retval 
+	       << GEndl;
+      
    }
    else { // it is a GDataCurve or GWorkspace
       Double_t fitValue = HasTheory() ? GetTheory()->GetPrediction() : GetFitValue(); 
@@ -489,8 +593,9 @@ Double_t Gfitter::GParameter::GetChiSquared() const
 
    return retval;
 }
+*/
 
-/*
+/* very old ...
 Double_t Gfitter::GParameter::GetChiSquared() const
 {
    GData* tmpData = dynamic_cast<GData*>(m_data);
