@@ -510,7 +510,7 @@ void Gfitter::GStore::DumpParameters()
    TString line; for (Int_t i=0; i<length; i++) line += "-";
 
    // print
-   m_logger << GEndl;
+   m_logger << kINFO << GEndl;
    m_logger << kINFO << line << GEndl;
    m_logger << kINFO << "G S t o r e   A c t i v e   P a r a m e t e r   D u m p " << GEndl;
    m_logger << kINFO << line << GEndl;
@@ -523,6 +523,7 @@ void Gfitter::GStore::DumpParameters()
    m_logger << kINFO << left
             << setw(maxL-1) << "Parameter" << "    "
             << setw(13) << "    Value" 
+            << setw(13) << " FitValue"
             << setw(26) << "             Gauss error"
             << setw(19) << "       Range error " << "|"
             << setw(11) << "     Theory" << " | "
@@ -538,7 +539,7 @@ void Gfitter::GStore::DumpParameters()
          m_logger << kINFO 
                   << left
                   << setw(maxL-1) << (*it)->GetFullName() << " ="
-                  << setw(9) << Form( valFormat, (*it)->GetValue() ) 
+                  << setw(9) << Form( valFormat, (*it)->GetValue() ) << " " << Form( valFormat, (*it)->GetFitValue() ) 
                   << setw(3) << "  +" << setw(7) << Form( errFormat, tmpData->GetErrGaussp() ) 
                   << setw(3) << "  -" << setw(7) << Form( errFormat, tmpData->GetErrGaussm() ) 
                   << setw(3) << "  +" << setw(5) << Form( rngFormat, tmpData->GetErrRangep() ) 
